function f = rechteSeite(t,yy)
    x   = yy(1,1);
    y   = yy(2,1);
    phi = yy(3,1);

    vx   = yy(4,1);
    vy   = yy(5,1);
    om   = yy(6,1);

    //Kollisionskräfte sind zunächst keine vorhanden:
    Fkollisionx = 0;
    Fkollisiony = 0;
    Mkollision  = 0;
    
    //Die linke und rechte Antriebskraft wird aus den PWM-Signalen
    //mit einem Verstärkungsfaktor gebildet:
    pwm_links  = 799;
    pwm_rechts = 799;
    Fantrieb_links  = pwm_links  * PWMFAKTOR;
    Fantrieb_rechts = pwm_rechts * PWMFAKTOR;

    //Die Antriebskräfte wirken in die Richtung, in die das Fahrzeug gerade orientiert ist:
    FanL = dr([Fantrieb_links;0],  phi);
    FanR = dr([Fantrieb_rechts;0], phi);

    //Vorbereitung der Dämpfungskräfte:
    //a) Verbindungsvektoren von S zu ABCD im Inertialkoordinatensystem
    rA = dr(PA,  phi);
    rB = dr(PB,  phi);
    rC = dr(PC,  phi);
    rD = dr(PD,  phi);
    //b) Aktuelle Geschwindigkeit in jedem Punkt ABCD bestimmen:
    //   vp = v + w x r
    vA = [vx;vy] + kv(om,rA); 
    vB = [vx;vy] + kv(om,rB); 
    vC = [vx;vy] + kv(om,rC); 
    vD = [vx;vy] + kv(om,rD); 
    //c) Dämpfungskräfte entgegen aktueller Geschw. im jeweiligen Punkt:
    FDampA = - DAMP*vA;
    FDampB = - DAMP*vB;
    FDampC = - DAMP*vC;
    FDampD = - DAMP*vD;

    //Reibkraft vorbereiten:
    //6N insgesamt, 1.5 pro Kraftangriffspunkt.
    //a) Einheitsvektor in Richtung der aktuellen Geschwindigkeit, der aber für kleine v fast verschwindet:
    klein  = 0.00000000001;
    kklein = 0.000001;
    vAe = (vA+[klein;klein])/(norm(vA)+kklein); //Unstetigkeit durch kleinen Fehler vermeiden
    vBe = (vB+[klein;klein])/(norm(vB)+kklein); //Unstetigkeit durch kleinen Fehler vermeiden
    vCe = (vC+[klein;klein])/(norm(vC)+kklein); //Unstetigkeit durch kleinen Fehler vermeiden
    vDe = (vD+[klein;klein])/(norm(vD)+kklein); //Unstetigkeit durch kleinen Fehler vermeiden

    FReibA = -1.5*vAe;
    FReibB = -1.5*vBe;
    FReibC = -1.5*vCe;
    FReibD = -1.5*vDe;

    //Die Kräfte setzen sich aus den einzelnen Komponenten zusammen:
//    FA = 0.5*FanR + FDampA + FReibA;
//    FB = 0.5*FanL + FDampB + FReibB;
//    FC = 0.5*FanL + FDampC + FReibC;
//    FD = 0.5*FanR + FDampD + FReibD;
    FA = 0.5*FanR + FDampA;
    FB = 0.5*FanL + FDampB;
    FC = 0.5*FanL + FDampC;
    FD = 0.5*FanR + FDampD;

    //Momente, die durch die Kräfte in ABCD wirken bestimmen:
    MA = kr(rA,FA);
    MB = kr(rB,FB);
    MC = kr(rC,FC);
    MD = kr(rD,FD);

    //Aufspaltung der Kräfte in x/y-Komponenten:
    FAx = FA(1);
    FAy = FA(2);
    FBx = FB(1);
    FBy = FB(2);
    FCx = FC(1);
    FCy = FC(2);
    FDx = FD(1);
    FDy = FD(2);

    f(1,1) = vx;
    f(2,1) = vy;
    f(3,1) = om;

    f(4,1) = (FAx+FBx+FCx+FDx  + Fkollisionx)/m;
    f(5,1) = (FAy+FBy+FCy+FDy  + Fkollisiony)/m;
    f(6,1) = (MA +MB +MC +MD   + Mkollision)/J;

endfunction